import UserConfig from "@/service/apiConfig/user_config";
import { action, computed, makeObservable, observable } from "mobx";
// 用户信息
import baseHttp from "@/service/base";
import BaseStore from "../baseStore";
import { UserDataType, UserInfos } from "@/model/userModel";

class UserStore extends BaseStore<UserDataType> {
    _userinfo: UserInfos = {}; // 用户信息
    isNeedLogin: boolean = false; // 是否需要登录

    constructor() {
        super(UserConfig)
        makeObservable(this, {
            logOut: action,
            login: action,
            _userinfo: observable,
            isNeedLogin: observable,
            openLoginDilog: action,
            userInfo: computed,
        })
    }
    get userInfo(): UserInfos {
        if (!this._userinfo.token) {
            let token = window.localStorage.getItem("token")
            this._userinfo.token = token;
        }
        return this._userinfo;
    }
    logOut() {
        this._userinfo.token = "";
        window.localStorage.clear();
        this.item = "";
    }
    async login(params: UserInfos) {
        let data = await baseHttp.post(UserConfig.LOGINURI, {
            acount: params.userName,
            passwd: params.passWord,
            loginType:5
        })
        this._userinfo = {
            userName: data.data.name,
            token: data.data.token,
            headerImag: data.data.headerImag,
            role: "",
            passWord: data.data.password,
        };
        window.localStorage.setItem("token", data.data.token ?? "");
    }
    openLoginDilog(){
        this.isNeedLogin = true;
    }
    closeLoginDilog(){
        this.isNeedLogin = false;
    }
}

// eslint-disable-next-line import/no-anonymous-default-export
export default new UserStore();